@@ -86,7 +86,7 @@
 #define KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KTEXTWIDGETS_NO_DEPRECATED
-#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KTEXTWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -210,7 +210,7 @@
 #define KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KTEXTWIDGETS_NO_DEPRECATED
-#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KTEXTWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -220,7 +220,7 @@
 #  ifdef KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
